Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1396)

Unified Diff: chrome/browser/media/router/issue.h

Issue 1993373002: [Media Router] Consistently refer to issue's learn more help page by ID. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Changes per imcheng@'s comments. Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/media/router/issue.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/media/router/issue.h
diff --git a/chrome/browser/media/router/issue.h b/chrome/browser/media/router/issue.h
index 60f33035b59d6b6d11a55bd652e582ae80b5f6f9..16744f502cd9c5488de58a503218dac40efcfcee 100644
--- a/chrome/browser/media/router/issue.h
+++ b/chrome/browser/media/router/issue.h
@@ -50,7 +50,8 @@ class Issue {
// |route_id|: The route id, or empty if global.
// |severity|: The severity of the issue.
// |is_blocking|: True if the issue needs to be resolved before continuing.
// |help_url|: Required if one of the actions is learn-more.
Issue(const std::string& title,
const std::string& message,
const IssueAction& default_action,
@@ -58,7 +59,7 @@ class Issue {
const MediaRoute::Id& route_id,
const Severity severity,
bool is_blocking,
- const std::string& helpUrl);
+ int help_page_id);
Issue(const Issue& other);
@@ -76,7 +77,7 @@ class Issue {
const Issue::Id& id() const { return id_; }
bool is_blocking() const { return is_blocking_; }
bool is_global() const { return route_id_.empty(); }
- const GURL& help_url() const { return help_url_; }
+ int help_page_id() const { return help_page_id_; }
bool Equals(const Issue& other) const;
@@ -89,7 +90,7 @@ class Issue {
Severity severity_;
Issue::Id id_;
bool is_blocking_;
- GURL help_url_;
+ int help_page_id_;
};
} // namespace media_router
« no previous file with comments | « no previous file | chrome/browser/media/router/issue.cc » ('j') | no next file with comments »
@@ -50,7 +50,8 @@ class Issue {
// |severity|: The severity of the issue.
// |is_blocking|: True if the issue needs to be resolved before continuing.
- // |help_url|: Required if one of the actions is learn-more.
+ // |help_page_id|: Required if one of the actions is learn-more. Passes in -1
+ // if the issue is not associated with a help page.
Issue(const std::string& title,
const std::string& message,

Powered by Google App Engine
This is Rietveld 408576698